@@ -4,7 +4,7 @@
  *
  * The Gnome Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation, Inc.,; either version 2 of the
  * License, or (at your option) any later version.
  *
  * The Gnome Library is distributed in the hope that it will be useful,
@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with the Gnome Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor
+ * Boston, MA 02110-1335 USA.
  *
  * Authors: John Sullivan <sullivan@eazel.com>
  */
@@ -29,8 +29,6 @@
 //char *  marlin_get_xdg_dir                      (const char *type);
 char    *marlin_get_accel_map_file      (void);
 
-void    marlin_restore_files_from_trash         (GList *files, GtkWindow *parent_window);
-
 void    marlin_get_rename_region (const char *filename, int *start_offset, int *end_offset, gboolean select_all);
 
 #endif /* MARLIN_FILE_UTILITIES_H */
